@import url("pocoo.css");
@import url("https://fonts.googleapis.com/css?family=Crimson+Text");

h1, h2, h3, h4, h5, h6, p.admonition-title, div.sphinxsidebar input {
  font-family: "Crimson Text", "Garamond", "Georgia", serif;
}

a, a.reference, a.footnote-reference {
  color: #a00;
  border-color: #a00;
}

a:hover {
  color: #d00;
  border-color: #d00;
}

p.version-warning {
  background-color: #d40;
}
